@@ -57,7 +57,7 @@ class JobManager:
     Kubernetes JobManager
 
     :param k8s_client: Kubernetes OpenAPI client
-    :param k8s_job_spec: path to YAML file, or dict, containing the spec for the job worker
+    :param k8s_job_spec: `dict` or path to YAML file containing the spec for the job worker
     :param namespace: Kubernetes k8s_namespace (default: 'default')
     """
 
@@ -73,7 +73,7 @@ class JobManager:
         Initialize the JobManager
 
         :param k8s_client: Kubernetes OpenAPI client
-        :param k8s_job_spec: dict, or path to YAML file containing the spec for the job worker
+        :param k8s_job_spec: `dict` or path to YAML file containing the spec for the job worker
         :param namespace: Kubernetes k8s_namespace
         """
 
